package com.sun.xml.internal.ws.policy.spi;

import com.sun.xml.internal.ws.policy.PolicyAssertion;
import java.util.Iterator;
import java.util.HashSet;
import javax.xml.namespace.QName;
import java.util.Collection;
import java.util.Set;

public abstract class AbstractQNameValidator implements PolicyAssertionValidator
{
    private final Set<String> supportedDomains;
    private final Collection<QName> serverAssertions;
    private final Collection<QName> clientAssertions;
    
    protected AbstractQNameValidator(Collection<QName> serverSideAssertions, Collection<QName> clientSideAssertions) {
        this.supportedDomains = new HashSet();
        if (serverSideAssertions != null) {
            this.serverAssertions = new HashSet(serverSideAssertions);
            for (QName assertion : this.serverAssertions) {
                this.supportedDomains.add(assertion.getNamespaceURI());
            }
        }
        else {
            this.serverAssertions = new HashSet(0);
        }
        if (clientSideAssertions != null) {
            this.clientAssertions = new HashSet(clientSideAssertions);
            for (QName assertion : this.clientAssertions) {
                this.supportedDomains.add(assertion.getNamespaceURI());
            }
        }
        else {
            this.clientAssertions = new HashSet(0);
        }
    }
    
    @Override
    public String[] declareSupportedDomains() {
        return (String[])this.supportedDomains.toArray(new String[this.supportedDomains.size()]);
    }
    
    @Override
    public PolicyAssertionValidator.Fitness validateClientSide(PolicyAssertion assertion) {
        return this.validateAssertion(assertion, this.clientAssertions, this.serverAssertions);
    }
    
    @Override
    public PolicyAssertionValidator.Fitness validateServerSide(PolicyAssertion assertion) {
        return this.validateAssertion(assertion, this.serverAssertions, this.clientAssertions);
    }
    
    private PolicyAssertionValidator.Fitness validateAssertion(PolicyAssertion assertion, Collection<QName> thisSideAssertions, Collection<QName> otherSideAssertions) {
        QName assertionName = assertion.getName();
        if (thisSideAssertions.contains(assertionName)) {
            return PolicyAssertionValidator.Fitness.SUPPORTED;
        }
        if (otherSideAssertions.contains(assertionName)) {
            return PolicyAssertionValidator.Fitness.UNSUPPORTED;
        }
        return PolicyAssertionValidator.Fitness.UNKNOWN;
    }
}
